function [Normal_Force,Tangential_Force,Torque,DeltaT,DeltaR,Status]=Apply_Contact_Laws(DeltaN,DeltaN_Prime,DeltaT,DeltaT_Prime,DeltaR,DeltaR_Prime,Contact_Radius,Effective_Mass,Law,Status,LAWS,TIME_STEP)
Law_Name=LAWS{Law,3};
Law_Parameters=LAWS{Law,4};
if strcmp(Law_Name,'Standard')
    Normal_Stiffness=Law_Parameters(1);
    Tangential_Stiffness=Law_Parameters(2);
    Friction_Coefficient=Law_Parameters(3);
    Damping_Coefficient=Law_Parameters(4);
    Torque=0;
    if DeltaN>0
        Normal_Force=0;
        Tangential_Force=0;
        DeltaT=0;
        Status=0;
    else
        Normal_Force=-Normal_Stiffness*DeltaN-Damping_Coefficient*sqrt(Effective_Mass*Normal_Stiffness)*DeltaN_Prime;
        if Normal_Force<0
            Normal_Force=0;
        end
        Tangential_Force=-Tangential_Stiffness*DeltaT;
        if abs(Tangential_Force)>Friction_Coefficient*Normal_Force
            Tangential_Force=sign(Tangential_Force)*Friction_Coefficient*Normal_Force;
            DeltaT=-Tangential_Force/Tangential_Stiffness;
            Status=1;
        else
            Status=2;
        end
    end
elseif strcmp(Law_Name,'Cohesion')
    Normal_Stiffness=Law_Parameters(1);
    Tangential_Stiffness=Law_Parameters(2);
    Damping_Coefficient=Law_Parameters(3);
    Attractive_Force=Law_Parameters(4);
    Attractive_Distance=Law_Parameters(5);
    Traction_Stiffness=Attractive_Force/Attractive_Distance;
    Torque=0;
    if DeltaN>Attractive_Distance
        Normal_Force=0;
        Tangential_Force=0;
        DeltaT=0;
        Status=0;
    elseif DeltaN>0
        Normal_Force=-Traction_Stiffness*DeltaN-Damping_Coefficient*sqrt(Effective_Mass*Normal_Stiffness)*DeltaN_Prime;
        Tangential_Force=-Tangential_Stiffness*DeltaT;
        if abs(Tangential_Force)>Attractive_Force
            Tangential_Force=sign(Tangential_Force)*Attractive_Force;
            DeltaT=-Tangential_Force/Tangential_Stiffness;
            Status=1;
        else
            Status=2;
        end
    else
        Normal_Force=-Normal_Stiffness*DeltaN-Damping_Coefficient*sqrt(Effective_Mass*Normal_Stiffness)*DeltaN_Prime;
        Tangential_Force=-Tangential_Stiffness*DeltaT;
        if abs(Tangential_Force)>Attractive_Force
            Tangential_Force=sign(Tangential_Force)*Attractive_Force;
            DeltaT=-Tangential_Force/Tangential_Stiffness;
            Status=1;
        else
            Status=2;
        end
    end
elseif strcmp(Law_Name,'Breakage')
    Normal_Stiffness=Law_Parameters(1);
    Tangential_Stiffness=Law_Parameters(2);
    Friction_Coefficient=Law_Parameters(3);
    Damping_Coefficient=Law_Parameters(4);
    Attractive_Force=Law_Parameters(5);
    Attractive_Distance=Law_Parameters(6);
    Traction_stiffness=Attractive_Force/Attractive_Distance;
    Torque=0;
    if Status==3
        if DeltaN>Attractive_Distance
            Normal_Force=0;
            Tangential_Force=0;
            DeltaT=0;
            Status=0;
        else
            Tangential_Force=-Tangential_Stiffness*DeltaT-Damping_Coefficient*sqrt(Effective_Mass*Normal_Stiffness)*DeltaT_Prime;
            if abs(Tangential_Force)>Attractive_Force
                Normal_Force=0;
                Tangential_Force=0;
                DeltaT=0;
                Status=0;
            else
                if DeltaN>0
                    Normal_Force=-Attractive_Force-Traction_stiffness*DeltaN-Damping_Coefficient*sqrt(Effective_Mass*Normal_Stiffness)*DeltaN_Prime;
                else
                    Normal_Force=-Attractive_Force-Normal_Stiffness*DeltaN-Damping_Coefficient*sqrt(Effective_Mass*Normal_Stiffness)*DeltaN_Prime;
                end
            end
        end
    else
        if DeltaN>0
            Normal_Force=0;
            Tangential_Force=0;
            DeltaT=0;
            Status=0;
        else
            Normal_Force=-Normal_Stiffness*DeltaN-Damping_Coefficient*sqrt(Effective_Mass*Normal_Stiffness)*DeltaN_Prime;
            if Normal_Force<0
                Normal_Force=0;
            end
            Tangential_Force=-Tangential_Stiffness*DeltaT;
            if abs(Tangential_Force)>Friction_Coefficient*Normal_Force
                Tangential_Force=sign(Tangential_Force)*Friction_Coefficient*Normal_Force;
                DeltaT=-Tangential_Force/Tangential_Stiffness;
                Status=1;
            else
                Status=2;
            end
        end
    end
elseif strcmp(Law_Name,'Rolling')
    Normal_Stiffness=Law_Parameters(1);
    Tangential_Stiffness=Law_Parameters(2);
    Friction_Coefficient=Law_Parameters(3);
    Damping_Coefficient=Law_Parameters(4);
    Rolling_Stiffness=Law_Parameters(5);
    Rolling_Friction_Coefficient=Law_Parameters(6);
    Rolling_Damping_Coefficient=Law_Parameters(7);
    if DeltaN>0
        Normal_Force=0;
        Tangential_Force=0;
        DeltaT=0;
        DeltaR=0;
        Torque=0;
        Status=0;
    else
        Normal_Force=-Normal_Stiffness*DeltaN-Damping_Coefficient*sqrt(Effective_Mass*Normal_Stiffness)*DeltaN_Prime;
        if Normal_Force<0
            Normal_Force=0;
        end
        Tangential_Force=-Tangential_Stiffness*DeltaT;
        if abs(Tangential_Force)>Friction_Coefficient*Normal_Force
            Tangential_Force=sign(Tangential_Force)*Friction_Coefficient*Normal_Force;
            DeltaT=-Tangential_Force/Tangential_Stiffness;
            Status=1;
        else
            Status=2;
        end
        Torque=-Rolling_Stiffness*DeltaR;
        if abs(Torque)>Rolling_Friction_Coefficient*Normal_Force*Contact_Radius
            Torque=sign(Torque)*Rolling_Friction_Coefficient*Normal_Force*Contact_Radius;
            DeltaR=-Torque/Rolling_Stiffness;
            Torque=Torque-Rolling_Damping_Coefficient*sqrt(Effective_Mass*Rolling_Stiffness)*DeltaR_Prime;
        end
    end
end