%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%                                                       %%
%%                        DEMLAB                         %%
%%        Discrete Element Modelling with Matlab         %%
%%                                                       %%
%%                     Main Program                      %%
%%               Version 1.5 ; March 2017                %%
%%                                                       %%
%%                Author: Guilhem Mollon                 %%
%%                                                       %%
%%            Developed at LaMCoS, INSA Lyon,            %%
%%                     Lyon, France                      %%
%%                      Year 2015                        %%
%%                                                       %%
%%            Please read enclosed .pdf file             %%
%%                                                       %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%% Load data %%%
clear all
User_Simulation_Data

%%% Initialization %%%
COUNT=0;
mkdir(Directory)
if Restart_Simulation==1
    Plot_Parameters=cat(2,Plot_Type,Rotation_Marker,Colored_Quantity_Discs,Discs_Quantity_Range(1),Discs_Quantity_Range(2),Colored_Quantity_Contacts,Contacts_Quantity_Range(1),Contacts_Quantity_Range(2),Plot_Axes,Print_Resolution,Maximum_Line_Width);
    [BALLS,WALLS,POSITIONS,VELOCITIES,VELOCITIES_HALF,ACCELERATIONS,NEIGHBOURS,CONTACTS,FORCES_ON_WALLS,RESULTING_FORCES_ON_WALLS,WALLS_CONTROL,MONITORED_VARIABLES,Detection_Distance,Last_print_length]=Initialize_Sample(Balls_Origin,Walls_Origin,Balls_Sets,Xvertices,Yvertices,Balls,Balls_File,Walls,Walls_File,LAWS,TIME_STEP);
elseif Restart_Simulation==2
    Plot_Parameters=cat(2,Plot_Type,Rotation_Marker,Colored_Quantity_Discs,Discs_Quantity_Range(1),Discs_Quantity_Range(2),Colored_Quantity_Contacts,Contacts_Quantity_Range(1),Contacts_Quantity_Range(2),Plot_Axes,Print_Resolution,Maximum_Line_Width);
    load(Restarting_File);
    Last_print_length=0;
    Time_ini=TIME+TIME_STEP;
    COUNT=COUNT+1;
    tic;
end
[BALLS,WALLS,POSITIONS,VELOCITIES,VELOCITIES_HALF,ACCELERATIONS,NEIGHBOURS,CONTACTS,MONITORED_VARIABLES]=User_Initial_Conditions(BALLS,WALLS,POSITIONS,VELOCITIES,VELOCITIES_HALF,ACCELERATIONS,NEIGHBOURS,CONTACTS,MONITORED_VARIABLES,LAWS,TIME_STEP);
[WallPlot,BallPlot,BrotPlot,NetworkPlot]=Plot_Sample(BALLS,WALLS,POSITIONS,CONTACTS,Plot_Parameters);
Check_Time_Step(BALLS,LAWS,TIME_STEP);
pause

%%% Main Loop %%%
for TIME=Time_ini:TIME_STEP:Time_fin
    %%% Update kinematic variables at the beginning of time-step %%%
    POSITIONS=Update_Positions(POSITIONS,VELOCITIES_HALF,TIME_STEP);
    VELOCITIES=Update_Velocities(VELOCITIES_HALF,ACCELERATIONS,TIME_STEP);
    [WALLS,WALLS_CONTROL]=User_Update_Walls(WALLS,WALLS_CONTROL,FORCES_ON_WALLS,RESULTING_FORCES_ON_WALLS,TIME,TIME_STEP);
    
    %%% Update forces at the beginning of time-step %%%
    NEIGHBOURS=Update_Neighbours(COUNT,Period_Neighbours,Neighbours_Parameter,NEIGHBOURS,POSITIONS,BALLS,WALLS);
    CONTACTS=Update_Contacts(CONTACTS,NEIGHBOURS,POSITIONS,VELOCITIES,LAWS,BALLS,WALLS,TIME_STEP,Detection_Distance);
    [FORCES_ON_BALLS,RESULTING_FORCES_ON_BALLS,FORCES_ON_WALLS,RESULTING_FORCES_ON_WALLS,ACCELERATIONS,CONTACTS]=Update_Forces(CONTACTS,BALLS,WALLS,LAWS,GRAVITY,TIME_STEP);
    
    %%% Update velocities at mid-time-step %%%
    VELOCITIES_HALF=Update_Velocities_Half(VELOCITIES_HALF,ACCELERATIONS,TIME_STEP);
    
    %%% Monitor, save, plot, print %%%
    MONITORED_VARIABLES=User_Monitoring(COUNT,Period_Monitoring,MONITORED_VARIABLES,TIME,TIME_STEP,BALLS,WALLS,POSITIONS,VELOCITIES,VELOCITIES_HALF,NEIGHBOURS,CONTACTS,LAWS,FORCES_ON_BALLS,FORCES_ON_WALLS,GRAVITY,RESULTING_FORCES_ON_BALLS,RESULTING_FORCES_ON_WALLS,ACCELERATIONS,WALLS_CONTROL);
    [WallPlot,BallPlot,BrotPlot,NetworkPlot]=Update_Plot(BALLS,WALLS,POSITIONS,VELOCITIES,FORCES_ON_BALLS,COUNT,TIME,Plot_Parameters,WallPlot,BallPlot,BrotPlot,NetworkPlot,Period_Plot);
    Snapshot_Print(Directory,COUNT,Period_Print,Print_Resolution)
    Save_State(Directory,COUNT,Period_Save,TIME,TIME_STEP,BallPlot,WallPlot,BrotPlot,BALLS,WALLS,WALLS_CONTROL,POSITIONS,VELOCITIES,VELOCITIES_HALF,NEIGHBOURS,CONTACTS,LAWS,FORCES_ON_BALLS,FORCES_ON_WALLS,GRAVITY,RESULTING_FORCES_ON_BALLS,RESULTING_FORCES_ON_WALLS,MONITORED_VARIABLES,ACCELERATIONS,Detection_Distance,Display_Time_Step,Last_print_length);
    
    %%% Update count %%%
    COUNT=COUNT+1;
    Last_print_length=Update_Prompt(Display_Time_Step,Last_print_length,COUNT);
end